==> matita_0.5.3.orig.tar.gz: matita-0.5.3/components/acic_procedural/acic2Procedural.mli <==
(* Copyright (C) 2003-2005, HELM Team.
 * 
 * This file is part of HELM, an Hypertextual, Electronic
 * Library of Mathematics, developed at the Computer Science
 * Department, University of Bologna, Italy.
 * 
 * HELM is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 * 
 * HELM is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with HELM; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston,
 * MA  02111-1307, USA.
 * 
 * For details, see the HELM World-Wide-Web page,
 * http://cs.unibo.it/helm/.
 *)

val procedural_of_acic_object:
   ids_to_inner_sorts:(Cic.id, Cic2acic.sort_kind) Hashtbl.t ->
   ids_to_inner_types:(Cic.id, Cic2acic.anntypes) Hashtbl.t -> 
   ?depth:int -> string -> Cic.annobj ->
      (Cic.annterm, Cic.annterm,
       Cic.annterm GrafiteAst.reduction, Cic.annterm CicNotationPt.obj, string)
      GrafiteAst.statement list

val procedural_of_acic_term:
   ids_to_inner_sorts:(Cic.id, Cic2acic.sort_kind) Hashtbl.t ->
   ids_to_inner_types:(Cic.id, Cic2acic.anntypes) Hashtbl.t -> 
   ?depth:int -> string -> Cic.context -> Cic.annterm ->
      (Cic.annterm, Cic.annterm,
       Cic.annterm GrafiteAst.reduction, Cic.annterm CicNotationPt.obj, string)
      GrafiteAst.statement list

==> matita_0.5.7.orig.tar.gz: matita-0.5.7/components/acic_procedural/acic2Procedural.mli <==
(* Copyright (C) 2003-2005, HELM Team.
 * 
 * This file is part of HELM, an Hypertextual, Electronic
 * Library of Mathematics, developed at the Computer Science
 * Department, University of Bologna, Italy.
 * 
 * HELM is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 * 
 * HELM is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with HELM; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston,
 * MA  02111-1307, USA.
 * 
 * For details, see the HELM World-Wide-Web page,
 * http://cs.unibo.it/helm/.
 *)

val procedural_of_acic_object:
   ids_to_inner_sorts:(Cic.id, Cic2acic.sort_kind) Hashtbl.t ->
   ids_to_inner_types:(Cic.id, Cic2acic.anntypes) Hashtbl.t -> ?info:string ->
   ?depth:int -> ?flavour:Cic.object_flavour -> string -> Cic.annobj ->
      (Cic.annterm, Cic.annterm,
       Cic.annterm GrafiteAst.reduction, Cic.annterm CicNotationPt.obj, string)
      GrafiteAst.statement list

val procedural_of_acic_term:
   ids_to_inner_sorts:(Cic.id, Cic2acic.sort_kind) Hashtbl.t ->
   ids_to_inner_types:(Cic.id, Cic2acic.anntypes) Hashtbl.t -> 
   ?depth:int -> string -> Cic.context -> Cic.annterm ->
      (Cic.annterm, Cic.annterm,
       Cic.annterm GrafiteAst.reduction, Cic.annterm CicNotationPt.obj, string)
      GrafiteAst.statement list

val debug: bool ref
